==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/fa-IR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'تأیید دارایی های حذف فله',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'بررسی دارایی برای حذف فله زیر کلیک کنید. به محض حذف این دارایی ها را می توان ترمیم کرد، اما ان ها دیگر قابل دسترسی با یوزر های دیگر نیستند.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'شما در حال حذف: دارایی های تعداد دارایی.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'به روز رسانی دارایی های فله',
    'bulk_update_help'	=> 'این فرم برای به روز رسانی دارایی های متعدد در یک بار را به شما اجازه می دهد. تنها قسمت ها نیاز به تغییر را پر کنید. هر زمینه های خالی سمت چپ بدون تغییر باقی می ماند. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'تحویل شده به

',
    'checkout_date'		=> 'چک کردن تاریخ
',
    'checkin_date'		=> 'تاریخ ورود
',
    'checkout_to'		=> 'اتمام به
',
    'cost'				=> 'هزینه خرید',
    'create'			=> 'ایجاد دارایی
',
    'date'				=> 'تاریخ خرید
',
    'depreciation'	    => 'استهلاک',
    'depreciates_on'	=> 'مستهلک کردن 
',
    'default_location'	=> ' پیش فرض محل سکونت
',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> ' تاریخ EOL
',
    'eol_rate'			=> ' نرخ EOL',
    'expected_checkin'  => ' چک در تاریخ را پر کنید',
    'expires'			=> 'تاریخ انقضا
',
    'fully_depreciated'	=> 'به طور کامل مستهلک شده',
    'help_checkout'		=> 'اگر شما مایل به اختصاص این دارایی ها هستید بلافاصله، "آماده به استقرار" از لیست وضعیت به بالا انتخاب کنید.',
    'mac_address'		=> 'مک ادرس',
    'manufacturer'		=> 'سازنده',
    'model'				=> 'مدل',
    'months'			=> 'ماه ها',
    'name'				=> 'نام دارایی',
    'notes'				=> 'نت ها',
    'order'				=> 'شماره سفارش',
    'qr'				=> 'کیو آر کد',
    'requestable'		=> 'کاربران ممکن است این دارایی هارا درخواست کنند
',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'انتخاب نوع وضعیت',
    'serial'			=> 'سریال',
    'status'			=> 'وضعیت',
    'tag'				=> 'برچسب دارایی
',
    'update'			=> 'به روز رسانی دارایی
',
    'warranty'			=> 'گارانتی',
        'warranty_expires'		=> 'انقضای ضمانت',
    'years'				=> 'سال ها',
    'asset_location' => 'بروزرسانی مکان دارایی',
    'asset_location_update_default_current' => 'بروزرسانی مکان پیش‌فرض AND مکان فعلی',
    'asset_location_update_default' => 'فقط بروزرسانی مکان پیش‌فرض',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'این وضعیت دارایی قابل استقرار نیست. این دارایی قابل پذیرش نیست.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'این وضعیت دارایی قابل استقرار است. این دارایی قابل پذیرش است.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'اطلاعات دلخواه
',
    'order_details'   => 'اطلاعات مربوط به سفارش
'
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/fa-IR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'تأیید دارایی های حذف فله',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'بررسی دارایی برای حذف فله زیر کلیک کنید. به محض حذف این دارایی ها را می توان ترمیم کرد، اما ان ها دیگر قابل دسترسی با یوزر های دیگر نیستند.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'شما در حال حذف: دارایی های تعداد دارایی.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'به روز رسانی دارایی های فله',
    'bulk_update_help'	=> 'این فرم برای به روز رسانی دارایی های متعدد در یک بار را به شما اجازه می دهد. تنها قسمت ها نیاز به تغییر را پر کنید. هر زمینه های خالی سمت چپ بدون تغییر باقی می ماند. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'تحویل شده به

',
    'checkout_date'		=> 'چک کردن تاریخ
',
    'checkin_date'		=> 'تاریخ ورود
',
    'checkout_to'		=> 'اتمام به
',
    'cost'				=> 'هزینه خرید',
    'create'			=> 'ایجاد دارایی
',
    'date'				=> 'تاریخ خرید
',
    'depreciation'	    => 'استهلاک',
    'depreciates_on'	=> 'مستهلک کردن 
',
    'default_location'	=> ' پیش فرض محل سکونت
',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> ' تاریخ EOL
',
    'eol_rate'			=> ' نرخ EOL',
    'expected_checkin'  => ' چک در تاریخ را پر کنید',
    'expires'			=> 'تاریخ انقضا
',
    'fully_depreciated'	=> 'به طور کامل مستهلک شده',
    'help_checkout'		=> 'اگر شما مایل به اختصاص این دارایی ها هستید بلافاصله، "آماده به استقرار" از لیست وضعیت به بالا انتخاب کنید.',
    'mac_address'		=> 'مک ادرس',
    'manufacturer'		=> 'سازنده',
    'model'				=> 'مدل',
    'months'			=> 'ماه ها',
    'name'				=> 'نام دارایی',
    'notes'				=> 'نت ها',
    'order'				=> 'شماره سفارش',
    'qr'				=> 'کیو آر کد',
    'requestable'		=> 'کاربران ممکن است این دارایی هارا درخواست کنند
',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'انتخاب نوع وضعیت',
    'serial'			=> 'سریال',
    'serial_required'	=> 'Asset :number requires a serial number',
    'serial_required_post_model_update'	=> ':asset_model have been updated to require a serial number. Please add a serial number for this asset.',
    'status'			=> 'وضعیت',
    'tag'				=> 'برچسب دارایی
',
    'update'			=> 'به روز رسانی دارایی
',
    'warranty'			=> 'گارانتی',
        'warranty_expires'		=> 'انقضای ضمانت',
    'years'				=> 'سال ها',
    'asset_location' => 'بروزرسانی مکان دارایی',
    'asset_location_update_default_current' => 'بروزرسانی مکان پیش‌فرض AND مکان فعلی',
    'asset_location_update_default' => 'فقط بروزرسانی مکان پیش‌فرض',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'این وضعیت دارایی قابل استقرار نیست. این دارایی قابل پذیرش نیست.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'processing' => 'در حال پردازش... ',
    'optional_infos'  => 'اطلاعات دلخواه
',
    'order_details'   => 'اطلاعات مربوط به سفارش
',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];
